import gurobipy as gb

m = gb.Model()

P = set(["A", "B", "N", "J"])
c = {"A": 0, "B": 590, "N": 110, "J": 300}

s = sum(c.values()) / len(c)

f = {}
for p in P:
    for q in P:
        f[p, q] = m.addVar(lb=0, vtype=gb.GRB.CONTINUOUS)

y = {}
for p in P:
    for q in P:
        y[p, q] = m.addVar(vtype=gb.GRB.BINARY)

for p in P:
    m.addConstr(
        gb.quicksum(f[p, q] for q in P)
        + c[p]
        - gb.quicksum(f[q, p] for q in P) == s
    )

M = sum(c.values())
#M = 1000000000
for p in P:
    for q in P:
        m.addConstr(f[p, q] <= y[p, q] * M)
        m.addConstr(y[p, q] <= f[p, q])

m.setObjective(gb.quicksum(y[p, q] for p in P for q in P), sense=gb.GRB.MINIMIZE)

m.optimize()

print('solution:')
for p in P:
    for q in P:
        print("{0} -> {1}: {2}".format(p, q, f[p, q].x))


print([y[p, q].x for p in P for q in P])

# always round results before casting to int!
print([int(round(f[p, q].x)) for p in P for q in P])

