import gurobi.*;

public class LP_example {
	public static void main(String[] args) throws Exception {
     // Create new environment.
		 GRBEnv env = new GRBEnv();

     // Create empty optimization model.
		 GRBModel model = new GRBModel(env);

		 // Create variables x, y.
     // addVar(lowerBound, upperBound, objectiveCoeff, variableType, name)
		 GRBVar x = model.addVar(0.0, GRB.INFINITY, 0.0, GRB.CONTINUOUS, "x");
		 GRBVar y = model.addVar(0.0, GRB.INFINITY, 0.0, GRB.CONTINUOUS, "y");

		 // Integrate new variables into model.
		 model.update();

		 // Set objective: maximize -x + 2y
		 GRBLinExpr obj = new GRBLinExpr();
		 obj.addTerm(-1.0, x);
     		 obj.addTerm(2.0, y);
		 model.setObjective(obj, GRB.MINIMIZE);

		 // Add constraint: -4x - 9y <= -18
		 GRBLinExpr cons1 = new GRBLinExpr();
		 cons1.addTerm(-4.0, x);
     		 cons1.addTerm(-9.0, y);
     		 // addConstr(leftHandSide, inequalityType, rightHandSide, name)
		 model.addConstr(cons1, GRB.LESS_EQUAL, -18.0, "cons1");

		 // Add constraint: 3/2x - y <= 27/4
		 GRBLinExpr cons2 = new GRBLinExpr();
		 cons2.addTerm(3.0 / 2.0, x);
     		 cons2.addTerm(-1.0, y);
		 model.addConstr(cons2, GRB.LESS_EQUAL, 27.0/4.0, "cons2");

		 // Add constraint: -8/17x + y <= 2
		 GRBLinExpr cons3 = new GRBLinExpr();
		 cons3.addTerm(-8.0/17.0, x);
     		 cons3.addTerm(1.0, y);
		 model.addConstr(cons3, GRB.LESS_EQUAL, 2.0, "cons3");

		 // Solve the model.
		 model.optimize();

     // Print the objective
     // and the values of the decision variables in the solution.
		 System.out.println(x.get(GRB.StringAttr.VarName)+ " " +x.get(GRB.DoubleAttr.X));
		 System.out.println(y.get(GRB.StringAttr.VarName) + " " +y.get(GRB.DoubleAttr.X));
		 System.out.println("Obj: " + model.get(GRB.DoubleAttr.ObjVal));
	}
}
